api.users.v1 package — Argus-Toolbelt 1.0 documentation

# api.users.v1 package

## Submodules

## api.users.v1.group module

Autogenerated API

`api.users.v1.group.` `find_groups`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, domain: list = None, type: str = None, subjectID: list = None, excludeSubjectID: list = None, parentID: list = None, ancestorID: list = None, get_aclAncestorID: list = None, get_aclCustomerID: list = None, excludeAncestorID: list = None, userName: list = None, email: list = None, mobile: list = None, searchString: str = None, languageID: list = None, requiredFunctionID: list = None, requiredFunctionCustomerID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', requireAllFunctions: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search group profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. domain (list) – type (str) – subjectID (list) – excludeSubjectID (list) – parentID (list) – ancestorID (list) – get_aclAncestorID (list) – get_aclCustomerID (list) – excludeAncestorID (list) – userName (list) – email (list) – mobile (list) – searchString (str) – languageID (list) – requiredFunctionID (list) – requiredFunctionCustomerID (int) – includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). requireAllFunctions (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 875, “limit”: 262, “responseCode”: 200, “count”: 341, “data”: [{“id”: 644, “userName”: “poolemadison”, “name”: “Bridget Ramos DDS”, “createdTimestamp”: 845987294, “createdByUser”: {“id”: 791, “customerID”: 502, “userName”: “charles14”, “name”: “Scott Arellano”}, “lastUpdatedTimestamp”: 86961963, “lastUpdatedByUser”: {“id”: 524, “customerID”: 151, “userName”: “juliawilson”, “name”: “John Allen”}, “properties”: {“additionalProperties”: “Start enter radio could recent.”}, “groupName”: “Great society several down with.”, “description”: “Power safe heavy few own.”, “ascendantIDs”: [854], “flags”: [“DAEMON_ACCOUNT”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Out until opportunity since leader possible his.”, “messageTemplate”: “Bar pay program long.”, “field”: “Must debate man head.”, “parameter”: {}, “timestamp”: 1073216127}], “currentPage”: 404, “size”: 648}

`api.users.v1.group.` `get_gropu_by_id`(groupId: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get group profile by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | groupId (int) – ID of group
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 361, “limit”: 755, “responseCode”: 200, “count”: 443, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “War building center energy.”, “messageTemplate”: “Particular Mr mean popular suffer.”, “field”: “Senior reality such factor suddenly talk.”, “parameter”: {}, “timestamp”: 1101466491}], “currentPage”: 129, “size”: 716}

`api.users.v1.group.` `get_group_by_name`(groupName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get group profile by name (PUBLIC)

  Return type: | `dict`
  Parameters: | groupName (str) – Group shortname
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 314, “limit”: 441, “responseCode”: 200, “count”: 815, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Fund drop side suggest.”, “messageTemplate”: “There example exist not property.”, “field”: “Leader campaign power expert.”, “parameter”: {}, “timestamp”: 871401684}], “currentPage”: 490, “size”: 47}

`api.users.v1.group.` `list_groups`(subjectID: list = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get group information (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectID (list) – IDs of groups offset (int) – Offset results limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 941, “limit”: 276, “responseCode”: 200, “count”: 891, “data”: [{“id”: 987, “customerID”: 923, “description”: “Focus close step very yard activity.”, “name”: “Michael Fox”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Even throw important.”, “messageTemplate”: “Only citizen party third why democratic.”, “field”: “Course certainly risk plan college animal risk plant.”, “parameter”: {}, “timestamp”: 52776254}], “currentPage”: 259, “size”: 387}

## api.users.v1.subject module

Autogenerated API

`api.users.v1.subject.` `find_subjects`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, domain: list = None, type: str = None, subjectID: list = None, excludeSubjectID: list = None, parentID: list = None, ancestorID: list = None, get_aclAncestorID: list = None, get_aclCustomerID: list = None, excludeAncestorID: list = None, userName: list = None, email: list = None, mobile: list = None, searchString: str = None, languageID: list = None, requiredFunctionID: list = None, requiredFunctionCustomerID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', requireAllFunctions: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search user or group profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. domain (list) – type (str) – subjectID (list) – excludeSubjectID (list) – parentID (list) – ancestorID (list) – get_aclAncestorID (list) – get_aclCustomerID (list) – excludeAncestorID (list) – userName (list) – email (list) – mobile (list) – searchString (str) – languageID (list) – requiredFunctionID (list) – requiredFunctionCustomerID (int) – includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). requireAllFunctions (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 604, “limit”: 228, “responseCode”: 200, “count”: 426, “data”: [{“id”: 234, “customerID”: 502, “name”: “Manuel Edwards”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Here director stop focus heavy participant.”, “messageTemplate”: “Prepare turn before ahead national research performance why.”, “field”: “Market owner difficult page degree new daughter.”, “parameter”: {}, “timestamp”: 1308380633}], “currentPage”: 280, “size”: 281}

`api.users.v1.subject.` `get_subject_by_id`(subjectID: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user or group profile by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectID (int) – ID of subject
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 936, “limit”: 568, “responseCode”: 200, “count”: 939, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Seven production character occur effect.”, “messageTemplate”: “Create idea management mention.”, “field”: “Type shake possible not.”, “parameter”: {}, “timestamp”: 1218257500}], “currentPage”: 952, “size”: 593}

`api.users.v1.subject.` `get_subject_by_name`(subjectName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user or group profile by name (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectName (str) – Username or group shortname
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 342, “limit”: 308, “responseCode”: 200, “count”: 160, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Better I future central vote discussion behind government.”, “messageTemplate”: “Lot free nearly oil near campaign maybe.”, “field”: “Country down issue view environment against.”, “parameter”: {}, “timestamp”: 1003676805}], “currentPage”: 571, “size”: 869}

`api.users.v1.subject.` `list_subjects`(subjectID: list = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user or group profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectID (list) – IDs of subjects offset (int) – Offset results limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 570, “limit”: 125, “responseCode”: 200, “count”: 64, “data”: [{“id”: 627, “customerID”: 614, “name”: “Donna Rodriguez”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Cultural view American talk.”, “messageTemplate”: “Ball itself against other culture.”, “field”: “Open reality billion.”, “parameter”: {}, “timestamp”: 1260389241}], “currentPage”: 257, “size”: 592}

## api.users.v1.user module

Autogenerated API

`api.users.v1.user.` `check_permission`(userId: int, function: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Validate user permission to perform function (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – ID of user function (str) – Function name
  Raises: | AuthenticationFailedException – on 401 ValidationFailedException – on 412 ForbiddenPermissionException – on 403 UserNotFoundException – on 404
  Returns: | {}

`api.users.v1.user.` `find_users`(limit: int = None, offset: int = None, includeFlags: int = None, excludeFlags: int = None, subCriteria: list = None, customerID: list = None, domain: list = None, type: str = None, subjectID: list = None, excludeSubjectID: list = None, parentID: list = None, ancestorID: list = None, get_aclAncestorID: list = None, get_aclCustomerID: list = None, excludeAncestorID: list = None, userName: list = None, email: list = None, mobile: list = None, searchString: str = None, languageID: list = None, requiredFunctionID: list = None, requiredFunctionCustomerID: int = None, includeDeleted: bool = 'False', exclude: bool = 'False', required: bool = 'False', requireAllFunctions: bool = 'False', json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Search user profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | limit (int) – Set this value to set max number of results. By default, no restriction on result set size. offset (int) – Set this value to skip the first (offset) objects. By default, return result from first object. includeFlags (int) – Only include objects which have includeFlags set. excludeFlags (int) – Exclude objects which have excludeFlags set. subCriteria (list) – customerID (list) – Restrict search to data belonging to specified customers. domain (list) – type (str) – subjectID (list) – excludeSubjectID (list) – parentID (list) – ancestorID (list) – get_aclAncestorID (list) – get_aclCustomerID (list) – excludeAncestorID (list) – userName (list) – email (list) – mobile (list) – searchString (str) – languageID (list) – requiredFunctionID (list) – requiredFunctionCustomerID (int) – includeDeleted (bool) – Set to true to include deleted objects. By default, exclude deleted objects. exclude (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria object will be excluded. required (bool) – Only relevant for subcriteria. If set to true, objects matching this subcriteria are required (AND-ed together with parent criteria). requireAllFunctions (bool) –
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 896, “limit”: 573, “responseCode”: 200, “count”: 99, “data”: [{“id”: 240, “customerID”: 643, “userName”: “dominguezlisa”, “name”: “Michael Booker”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Last whether truth laugh certainly artist.”, “messageTemplate”: “Newspaper drop car card.”, “field”: “Visit evening medical future.”, “parameter”: {}, “timestamp”: 1091730917}], “currentPage”: 33, “size”: 155}

`api.users.v1.user.` `get_functions`(userId: int, onlyRoles: bool = None, keywords: list = None, offset: int = 0, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  List a user’s permission functions regardless of customer (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – ID of user onlyRoles (bool) – Only return functions marked as roles keywords (list) – Filter functions by keywords on name and description offset (int) – Skip a number of functions limit (int) – Maximum number of returned functions
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 UserNotFoundException – on 404
  Returns: | {“offset”: 484, “limit”: 637, “responseCode”: 200, “count”: 444, “data”: [{“id”: 630, “name”: “Ms. Meghan Boyd”, “description”: “Town cause receive appear baby knowledge.”, “securityLevel”: “EXTERNAL”, “flags”: [“ROLE”]}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Good suddenly his.”, “messageTemplate”: “Yes plant indeed.”, “field”: “Later item prevent check another.”, “parameter”: {}, “timestamp”: 996433058}], “currentPage”: 625, “size”: 681}

`api.users.v1.user.` `get_profile`(userId: int, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user profile by ID (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – ID of user
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 527, “limit”: 929, “responseCode”: 200, “count”: 746, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Employee theory magazine perhaps against arrive.”, “messageTemplate”: “Help through rule institution billion.”, “field”: “Common plan early blue seem.”, “parameter”: {}, “timestamp”: 342686282}], “currentPage”: 251, “size”: 527}

`api.users.v1.user.` `get_user_by_username`(userName: str, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user profile by username (PUBLIC)

  Return type: | `dict`
  Parameters: | userName (str) – Username
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 650, “limit”: 145, “responseCode”: 200, “count”: 20, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Condition color enter painting no risk however.”, “messageTemplate”: “Fact treat bag physical gas single.”, “field”: “Affect year determine time.”, “parameter”: {}, “timestamp”: 1427104854}], “currentPage”: 207, “size”: 901}

`api.users.v1.user.` `list_users`(subjectID: list = None, offset: int = None, limit: int = 25, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Get user profiles (PUBLIC)

  Return type: | `dict`
  Parameters: | subjectID (list) – IDs of users offset (int) – Offset results limit (int) – Limit results
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403
  Returns: | {“offset”: 453, “limit”: 107, “responseCode”: 200, “count”: 891, “data”: [{“id”: 365, “customerID”: 764, “userName”: “denise92”, “name”: “Whitney Howard”}], “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Per economic nature hotel affect.”, “messageTemplate”: “Treat type focus ago speech church.”, “field”: “Wear forward others doctor spring.”, “parameter”: {}, “timestamp”: 1110900906}], “currentPage”: 505, “size”: 77}

`api.users.v1.user.` `update_profile_picture_for_user`(userId: int, picture: str = None, json: bool = True, verify: bool = True, apiKey: str = '', authentication: dict = {}) → dict

  Upload and modify the user image (PUBLIC)

  Return type: | `dict`
  Parameters: | userId (int) – ID of user to change image for picture (str) – Image data URL
  Raises: | AuthenticationFailedException – on 401 ValidationErrorException – on 412 AccessDeniedException – on 403 ObjectNotFoundException – on 404
  Returns: | {“offset”: 936, “limit”: 603, “responseCode”: 200, “count”: 623, “metaData”: {“additionalProperties”: {}}, “messages”: [{“message”: “Next enough play pass news general same.”, “messageTemplate”: “Analysis no site purpose.”, “field”: “State wish other enjoy draw kitchen.”, “parameter”: {}, “timestamp”: 191395616}], “currentPage”: 856, “size”: 636}

## Module contents